<?php

proon_locale_on();

// These UI constants are for strings used in the ... wait for it ... UI
define(PROON_UI_PAGE_TITLE, _("Options for Pruning Folders"));
define(PROON_UI_GOTO_HELP, _("?"));
define(PROON_UI_BACKFROM_HELP, _("^"));
define(PROON_UI_HELP_ALL, _("Help and Explanations"));
define(PROON_UI_HELP_FOLDER, _("Action Buttons and Per-Folder Values"));
define(PROON_UI_ITEM, _("Item"));
define(PROON_UI_DESCRIPTION, _("Description"));
define(PROON_UI_SETTING, _("Setting"));
define(PROON_UI_SITE_PREF, _("Site Setting"));
define(PROON_UI_DATE_SPAN, _("Date Span"));
define(PROON_UI_SIZE_SPAN, _("Size Span"));
define(PROON_UI_COUNT_SPAN, _("Count Span"));
define(PROON_UI_UNSEEN_TOO, _("Unseen, too"));
define(PROON_UI_MANUAL_ONLY, _("Manual Only"));
define(PROON_UI_SHOW, _("Show Effect"));
define(PROON_UI_PRUNE, _("Prune Now"));
define(PROON_UI_SHOW_ALL, _("Show All Effects"));
define(PROON_UI_PRUNE_ALL, _("Prune All Folders"));
define(PROON_UI_SAVE, _("Save All"));
define(PROON_UI_USER_PREFS, _("User Preferences"));
define(PROON_UI_INTERVAL, _("Recurring Prune Interval"));
define(PROON_UI_LOGIN_N, _("Sign-on Prune Frequency"));
define(PROON_UI_VIA_TRASH, _("Prune via Trash"));
define(PROON_UI_UNSUBSCRIBED, _("Unsubscribed Folders"));
define(PROON_UI_TRASH_ORDER, _("Trash Pruning Order"));
define(PROON_UI_DATE_PRUNING, _("Date Pruning"));
define(PROON_UI_SIZE_PRUNING, _("Size Pruning"));
define(PROON_UI_COUNT_PRUNING, _("Count Pruning"));
define(PROON_UI_SC_ORDER, _("Size and Count Pruning Order"));
define(PROON_UI_MESSAGE_AFTER, _("Email Report"));
define(PROON_UI_SCREEN_AFTER, _("On-Screen Report"));
define(PROON_UI_USE_COLORS, _("Use Theme Colors"));
define(PROON_UI_PRUNE_LINK, _("Left Pane Prune Link"));
define(PROON_UI_REFRESH_RIGHT, _("<i>Refresh main </i>Folders<i> list</i>"));
define(PROON_UI_FOLDER_TABLE, _("Folder Table"));
define(PROON_UI_SFOLDER_TABLE, _("Subscribed Folders"));
define(PROON_UI_UFOLDER_TABLE, _("Unsubscribed Folders"));
define(PROON_UI_NFOLDER_TABLE, _("Nonexistent Folders"));
define(PROON_UI_FOLDER, _("Folder"));
define(PROON_UI_BOP, _("Bottom of Page"));
define(PROON_UI_ENABLED, _("Enabled"));
define(PROON_UI_DISABLED, _("Disabled"));
define(PROON_UI_FIRST, _("First"));
define(PROON_UI_NATURAL, _("Natural"));
define(PROON_UI_LAST, _("Last"));
define(PROON_UI_CONSIDER_DATE, _("Consider by Date"));
define(PROON_UI_BY_DATE, _("by Date"));
define(PROON_UI_CONSIDER_SIZE, _("Consider by Size"));
define(PROON_UI_BY_SIZE, _("by Size"));
define(PROON_PRUNING_DOTDOTDOT, _("Pruning ..."));

proon_locale_off();
?>
